EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'CondaPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'CondaPackage_Id',
    /* Description_Text        */ 'Creates a new Conda package or updates an existing one.',
	/* Remarks_Text            */ 'Make sure to also call CondaPackages_SetLatestVersion as necessary.'
GO

IF OBJECT_ID('[CondaPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [CondaPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [CondaPackages_CreateOrUpdatePackage]
(
	@Feed_Id INT,
	@Package_Name NVARCHAR(200),
	@Subdir_Name VARCHAR(50),
	@Version_Text VARCHAR(255),
	@Build_Text VARCHAR(100),
	@Build_Number INT,
	@MD5Hash_Bytes BINARY(16),
	@SHA1Hash_Bytes BINARY(20),
	@SHA256Hash_Bytes BINARY(32),
	@IconHash_Bytes BINARY(16),
	@Icon_Size INT,
	@Package_Size BIGINT,
	@Metadata_Bytes VARBINARY(MAX),
	@Cached_Indicator YNINDICATOR,
	@Published_Date DATETIME,
	@Summary_Text NVARCHAR(MAX),
	@Description_Text NVARCHAR(MAX),
	@ArchiveType_Code CHAR(1),
	@Download_Count INT = NULL,
	@CondaPackage_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @CondaPackage_Id = (SELECT [CondaPackage_Id] FROM [CondaPackages] WHERE [Feed_Id] = @Feed_Id AND [Package_Name] = @Package_Name AND [Subdir_Name] = @Subdir_Name AND [Version_Text] = @Version_Text AND [Build_Text] = @Build_Text AND [ArchiveType_Code] = @ArchiveType_Code)

	IF @CondaPackage_Id IS NOT NULL BEGIN

		UPDATE [CondaPackages]
		   SET [Build_Number] = @Build_Number,
		       [MD5Hash_Bytes] = @MD5Hash_Bytes,
		       [SHA1Hash_Bytes] = @SHA1Hash_Bytes,
			   [SHA256Hash_Bytes] = @SHA256Hash_Bytes,
			   [IconHash_Bytes] = @IconHash_Bytes,
			   [Icon_Size] = @Icon_Size,
			   [Package_Size] = @Package_Size,
			   [Metadata_Bytes] = @Metadata_Bytes,
			   [Cached_Indicator] = @Cached_Indicator,
			   [Published_Date] = @Published_Date,
			   [Summary_Text] = @Summary_Text,
			   [Description_Text] = @Description_Text
		 WHERE [CondaPackage_Id] = @CondaPackage_Id

	END ELSE BEGIN

		INSERT INTO [CondaPackages]
		(
			[Feed_Id],
			[Package_Name],
			[Subdir_Name],
			[Version_Text],
			[Build_Text],
			[Build_Number],
			[MD5Hash_Bytes],
			[SHA1Hash_Bytes],
			[SHA256Hash_Bytes],
			[Download_Count],
			[IconHash_Bytes],
			[Icon_Size],
			[Package_Size],
			[Metadata_Bytes],
			[Cached_Indicator],
			[Latest_Indicator],
			[Published_Date],
			[ArchiveType_Code],
			[Summary_Text],
			[Description_Text]
		)
		VALUES
		(
			@Feed_Id,
			@Package_Name,
			@Subdir_Name,
			@Version_Text,
			@Build_Text,
			@Build_Number,
			@MD5Hash_Bytes,
			@SHA1Hash_Bytes,
			@SHA256Hash_Bytes,
			COALESCE(@Download_Count, 0),
			@IconHash_Bytes,
			@Icon_Size,
			@Package_Size,
			@Metadata_Bytes,
			@Cached_Indicator,
			'N',
			@Published_Date,
			@ArchiveType_Code,
			@Summary_Text,
			@Description_Text
		)

		SET @CondaPackage_Id = SCOPE_IDENTITY()

	END

	EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Subdir_Name', @Subdir_Name, 'Package_Name', @Package_Name, 'Package_Version', @Version_Text, 'Package_Build', @Build_Text

	UPDATE [Feeds]
	   SET [FeedState_Number] = COALESCE([FeedState_Number], 0) + 1,
	       [LastPackageUpdate_Date] = GETUTCDATE()
	 WHERE [Feed_Id] = @Feed_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [CondaPackages_CreateOrUpdatePackage] TO [ProGetUser_Role]
GO