EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'CondaPackages_DeletePackage',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Deletes the specified Conda package.',
	/* Remarks_Text            */ 'Make sure to also call CondaPackages_SetLatestVersion as necessary.'
GO

IF OBJECT_ID('[CondaPackages_DeletePackage]') IS NOT NULL DROP PROCEDURE [CondaPackages_DeletePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [CondaPackages_DeletePackage]
(
	@CondaPackage_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Outputs TABLE ([Feed_Id] INT, [Subdir_Name] VARCHAR(50), [Package_Name] VARCHAR(200), [Version_Text] VARCHAR(255), [Build_Text] VARCHAR(100))

	DELETE [CondaPackages]
	 OUTPUT deleted.[Feed_Id], deleted.[Subdir_Name], deleted.[Package_Name], deleted.[Version_Text], deleted.[Build_Text] INTO @Outputs
	 WHERE [CondaPackage_Id] = @CondaPackage_Id

	IF EXISTS(SELECT * FROM @Outputs) BEGIN

		DECLARE @Feed_Id INT
		DECLARE @Subdir_Name VARCHAR(50)
		DECLARE @Package_Name VARCHAR(200)
		DECLARE @Version_Text VARCHAR(255)
		DECLARE @Build_Text VARCHAR(100)

		SELECT TOP 1 @Feed_Id = [Feed_Id],
		             @Subdir_Name = [Subdir_Name],
		             @Package_Name = [Package_Name],
			         @Version_Text = [Version_Text],
			         @Build_Text = [Build_Text]
		  FROM @Outputs

		UPDATE [Feeds]
		   SET [FeedState_Number] = COALESCE([FeedState_Number], 0) + 1,
		       [LastPackageUpdate_Date] = GETUTCDATE()
		 WHERE [Feed_Id] = @Feed_Id

		EXEC [Events_RaiseEvent] 'PKGDEL', @Feed_Id, 'Subdir_Name', @Subdir_Name, 'Package_Name', @Package_Name, 'Package_Version', @Version_Text, 'Package_Build', @Build_Text

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [CondaPackages_DeletePackage] TO [ProGetUser_Role]
GO