EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Packages_RecordPackagePromotion',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'PackagePromotion_Id',
    /* Description_Text        */ 'Records a package promotion to a different feed.'
GO

IF OBJECT_ID('[Packages_RecordPackagePromotion]') IS NOT NULL DROP PROCEDURE [Packages_RecordPackagePromotion]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Packages_RecordPackagePromotion]
(
	@Package_Name NVARCHAR(200),
    @Version_Text NVARCHAR(100),
    @Group_Name NVARCHAR(200),
    @From_Feed_Name NVARCHAR(50),
    @To_Feed_Name NVARCHAR(50),
    @PromotedBy_User_Name USERNAME,
    @Comments_Text NVARCHAR(MAX),
    @New_Version_Text NVARCHAR(100) = NULL,
    @PackagePromotion_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @From_Feed_Id INT
    DECLARE @To_Feed_Id INT

    SELECT @From_Feed_Id = [Feed_Id] FROM [Feeds] WHERE [Feed_Name] = @From_Feed_Name
    SELECT @To_Feed_Id = [Feed_Id] FROM [Feeds] WHERE [Feed_Name] = @To_Feed_Name

    IF @From_Feed_Id IS NULL
    BEGIN
        RAISERROR('The specified from feed %s was not found.',16,2, @From_Feed_Name)
        ROLLBACK
        RETURN
    END
    IF @To_Feed_Id IS NULL
    BEGIN
        RAISERROR('The specified to feed %s was not found.',16,2, @To_Feed_Name)
        ROLLBACK
        RETURN
    END


    INSERT INTO [PackagePromotions]
    (
         [Package_Name]
        ,[Group_Name]
        ,[Version_Text]
        ,[New_Version_Text]
        ,[From_Feed_Id]
        ,[To_Feed_Id]
        ,[Promoted_Date]
        ,[PromotedBy_User_Name]
        ,[Comments_Text]
    )
    VALUES
    (
         @Package_Name
        ,NULLIF(@Group_Name, '')
        ,@Version_Text
        ,@New_Version_Text
        ,@From_Feed_Id
        ,@To_Feed_Id
        ,GETUTCDATE()
        ,@PromotedBy_User_Name
        ,@Comments_Text
    )

    SET @PackagePromotion_Id = SCOPE_IDENTITY()

    COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Packages_RecordPackagePromotion] TO [ProGetUser_Role]
GO